@@ -1,6 +1,6 @@
 #' A set of function to test conformance with LAS specifications
 #'
-#' A set of function to test conformance with \href{http://www.asprs.org/a/society/committees/standards/LAS_1_4_r13.pdf}{LAS specification}.
+#' A set of function to test conformance with \href{http://www.asprs.org/wp-content/uploads/2019/07/LAS_1_4_r15.pdf}{LAS specification}.
 #' Tools reserved to developpers and not intended to be used by regular users. The functions return TRUE
 #' or FALSE by default without more information. If behavior is 'warning' functions throw a warning
 #' for each fail and return FALSE if any warning TRUE otherwise. If behavior is 'stop' functions throw
@@ -614,10 +614,10 @@ is_valid_ScanAngle = function(data, behavior = "bool")
   if (is.null(data[["ScanAngle"]]))
     return(error_handling_engine(errors, behavior))
 
-  if (min(data[["ScanAngle"]]) < -180)
+  if (min(data[["ScanAngle"]]) < -196.6)
     errors = append(errors, "Invalid data: ScanAngle greater than -180 degrees.")
 
-  if (max(data[["ScanAngle"]]) > 180)
+  if (max(data[["ScanAngle"]]) > 196.6)
     errors = append(errors, "Invalid data: ScanAngle greater than 180 degrees")
 
   return(error_handling_engine(errors, behavior))
@@ -831,6 +831,25 @@ is_compliant_RGB = function(data, behavior = "bool")
   return(error_handling_engine(errors, behavior))
 }
 
+#' @export
+#' @rdname las_specification_tools
+is_compliant_ScanAngle = function(data, behavior = "bool")
+{
+  errors = character(0)
+
+  if (is.null(data[["ScanAngle"]]))
+    return(error_handling_engine(errors, behavior))
+
+  if (min(data[["ScanAngle"]]) < -180)
+    errors = append(errors, "Invalid data: ScanAngleRank greater than -90 degrees.")
+
+  if (max(data[["ScanAngle"]]) > 180)
+    errors = append(errors, "Invalid data: ScanAngleRank greater than 90 degrees")
+
+  return(error_handling_engine(errors, behavior))
+}
+
+
 #' @export
 #' @rdname las_specification_tools
 is_compliant_ScanAngleRank = function(data, behavior = "bool")
